From 3cf5f56e828edcac176634cf9103f86d30e78316 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Mattias=20Ryrl=C3=A9n?= <mattiasr@op5.com>
Date: Fri, 30 Aug 2013 15:25:53 +0200
Subject: [PATCH] test: Allow to build on single core cpus
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

We should be able to run our test and allow to build on single core machines.

Signed-off-by: Mattias Ryrlén <mattiasr@op5.com>
---
 lib/nsutils.c      | 16 +++++++++++-----
 lib/nsutils.h      |  8 +++++++-
 lib/test-nsutils.c | 13 ++++++++++---
 3 files changed, 28 insertions(+), 9 deletions(-)

diff --git a/lib/nsutils.c b/lib/nsutils.c
index dc6386e..8ee2419 100644
--- a/lib/nsutils.c
+++ b/lib/nsutils.c
@@ -21,13 +21,13 @@
 #  endif
 #endif
 
-int online_cpus(void)
+int real_online_cpus(void)
 {
 #ifdef _SC_NPROCESSORS_ONLN
-	long ncpus;
+	int ncpus;
 
-	if ((ncpus = (long)sysconf(_SC_NPROCESSORS_ONLN)) > 0)
-		return (int)ncpus;
+	if ((ncpus = (int)sysconf(_SC_NPROCESSORS_ONLN)) > 0)
+		return ncpus;
 #elif defined(hpux) || defined(__hpux) || defined(_hpux)
 	struct pst_dynamic psd;
 
@@ -35,7 +35,13 @@ int online_cpus(void)
 		return (int)psd.psd_proc_cnt;
 #endif
 
-	return 1;
+	return 0;
+}
+
+int online_cpus(void)
+{
+	int ncpus = real_online_cpus();
+	return ncpus > 0 ? ncpus : 1;
 }
 
 int tv_delta_msec(const struct timeval *start, const struct timeval *stop)
diff --git a/lib/nsutils.h b/lib/nsutils.h
index 553a4e3..82988f0 100644
--- a/lib/nsutils.h
+++ b/lib/nsutils.h
@@ -67,7 +67,13 @@ static inline unsigned int ranged_urand(unsigned int low, unsigned int high)
 
 /**
  * Get number of online cpus
- * @return Number of kernel-handled cpu cores
+ * @return Number of kernel-handled cpu cores or 0 as fallback
+ */
+extern int real_online_cpus(void);
+
+/**
+ * Wrapper for online_cpus to allow fallback
+ * @return Number of kernel-handled cpu core or 1 as fallback
  */
 extern int online_cpus(void);
 
diff --git a/lib/test-nsutils.c b/lib/test-nsutils.c
index 1a23ee1..dd2e7d0 100644
--- a/lib/test-nsutils.c
+++ b/lib/test-nsutils.c
@@ -31,10 +31,17 @@ int main(int argc, char **argv)
 	asprintf(&s1, "arg varg foo %d", 12);
 	s2 = mkstr("arg varg foo %d", 12);
 	ok_str(s1, s2, "mkstr() must build proper strings");
-	if (online_cpus() > 1) {
-		t_pass("%d online cpus detected", online_cpus());
+	if (real_online_cpus() > 0) {
+		t_pass("%d online cpus detected", real_online_cpus());
 	} else {
-		t_fail("Do you really have only one cpu core?");
+		t_fail("Can't really determine the amount of cpus");
 	}
+
+	if (real_online_cpus() == online_cpus()) {
+		t_pass("online cpus match-up");
+	} else {
+		t_fail("online cpus mismatch");
+	}
+
 	return t_end();
 }
-- 
1.8.3.4

